command

package
v0.7.10 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 13, 2026 License: Apache-2.0 Imports: 18 Imported by: 0

Documentation

Overview

Copyright 2024 The Scitix Authors.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Copyright 2024 The Scitix Authors.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Copyright 2024 The Scitix Authors.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Copyright 2024 The Scitix Authors.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Copyright 2024 The Scitix Authors.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

This section is empty.

Variables

var (
	// Version is the full version string (e.g. v0.7.6.post1), set by ldflags at build time.
	// When set, it is used for display instead of Major.Minor.Patch.
	Version   = ""
	Major     = ""
	Minor     = ""
	Patch     = ""
	GitCommit = "none"
	GoVersion = "none"
	BuildTime = "unknown"
)

Functions

func NewConfigCmd

func NewConfigCmd() *cobra.Command

NewConfigCmd creates the "config" command group.

func NewDaemonCmd

func NewDaemonCmd() *cobra.Command

NewDaemonCmd creates and returns a subcommand instance for running in daemon mode, configuring the basic attributes of the command.

func NewExporterCmd added in v0.7.6

func NewExporterCmd() *cobra.Command

func NewRootCmd

func NewRootCmd() *cobra.Command

NewRootCmd creates and returns the root command (sichek command) instance, configures basic usage information, and adds subcommands.

func NewVersionCmd

func NewVersionCmd() *cobra.Command

Types

This section is empty.

Directories

Path Synopsis
Package spec provides CLI-layer helpers for resolving sichek spec/config files.
Package spec provides CLI-layer helpers for resolving sichek spec/config files.

Jump to