Documentation
¶
Overview ¶
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2024 The Scitix Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
- Variables
- func CheckNcclPerf(numGpus int, gpulist, beginBuffer, endBuffer string, disableNvls bool, ...) (*common.Result, error)
- func DetermineComponentsToCheck(enableComponents string, ignoredComponents string, cfgFile string, ...) []string
- func GetComponentsFromConfig(cfgFile string) ([]string, error)
- func GetDefaultNcclTestPath(testBin string) (string, error)
- func NewAllCmd() *cobra.Command
- func NewCPUCmd() *cobra.Command
- func NewComponent(componentName string, cfgFile string, specFile string, ...) (common.Component, error)
- func NewDmesgCmd() *cobra.Command
- func NewEthernetCmd() *cobra.Command
- func NewGpfsCmd() *cobra.Command
- func NewGpuEventsCommand() *cobra.Command
- func NewIBLinkCheckCmd() *cobra.Command
- func NewIBPerftestCmd() *cobra.Command
- func NewInfinibandCmd() *cobra.Command
- func NewMemoryCmd() *cobra.Command
- func NewNcclPerftestCmd() *cobra.Command
- func NewNvidiaCmd() *cobra.Command
- func NewPcieTopoCmd() *cobra.Command
- func NewPodLogCmd() *cobra.Command
- func NewRoCEGidEqualCheckCmd() *cobra.Command
- func NewRoCEGidsCheckCmd() *cobra.Command
- func NewRoCEPerftestCmd() *cobra.Command
- func NewSyslogCmd() *cobra.Command
- func NewTransceiverCmd() *cobra.Command
- func PrintCheckResults(summaryPrint bool, checkResult *CheckResults)
- func PrintNcclPerfInfo(result *common.Result) bool
- type CheckResults
- type Config
Constants ¶
This section is empty.
Variables ¶
Functions ¶
func CheckNcclPerf ¶
func DetermineComponentsToCheck ¶
func DetermineComponentsToCheck(enableComponents string, ignoredComponents string, cfgFile string, logField string) []string
DetermineComponentsToCheck determines which components to check based on enable-components flag, ignore-components flag, and the configuration file. Parameters:
- enableComponents: comma-separated list of components to enable (from -E flag), empty string means use config
- ignoredComponents: list of components to ignore (from -I flag)
- cfgFile: path to the user config file
- logField: field name for logging (e.g., "all" or "daemon")
Returns the list of component names to check.
func GetComponentsFromConfig ¶
GetComponentsFromConfig extracts component names from default_user_config.yaml. It returns only components with enable=true (excluding "metrics").
func GetDefaultNcclTestPath ¶
func NewAllCmd ¶
NewAllCmd creates a new cobra.Command for performing health checks on all components. It sets up the command with a context that times out after AllCmdTimeout, and defines the command's usage, short description, and long description. The command iterates over a list of default components, performs health checks on each, and prints the results. Flags: - verbos: Enable verbose output (default: false) - eventonly: Print events output only (default: false)
func NewComponent ¶
func NewDmesgCmd ¶
func NewEthernetCmd ¶ added in v0.7.7
func NewGpfsCmd ¶
NewGpfsCmd creates and returns a subcommand instance for running in Gpfs, configuring the basic attributes of the command.
func NewGpuEventsCommand ¶
func NewIBLinkCheckCmd ¶
func NewIBPerftestCmd ¶
func NewInfinibandCmd ¶
func NewMemoryCmd ¶
NewMemoryCmd creates and returns a subcommand instance for representing memory-related operations, configuring the basic attributes of the command.
func NewNcclPerftestCmd ¶
func NewNvidiaCmd ¶
NewNvidiaCmd creates and returns a subcommand instance for representing gpu-related operations, configuring the basic attributes of the command.
func NewPcieTopoCmd ¶
func NewPodLogCmd ¶
func NewRoCEGidEqualCheckCmd ¶
func NewRoCEGidsCheckCmd ¶
func NewRoCEPerftestCmd ¶
func NewSyslogCmd ¶
func NewTransceiverCmd ¶ added in v0.7.8
func PrintCheckResults ¶
func PrintCheckResults(summaryPrint bool, checkResult *CheckResults)
func PrintNcclPerfInfo ¶
Types ¶
type CheckResults ¶
type CheckResults struct {
// contains filtered or unexported fields
}
func RunComponentCheck ¶
type Config ¶
type Config struct {
NumGpus int
Gpulist string
TestBin string
DisableNvls bool
// IBHCA controls NCCL_IB_HCA selection:
// "" → auto-detect active RoCE VFs (respects an externally
// exported NCCL_IB_HCA)
// "off"/"none"/ → leave NCCL_IB_HCA at its default, no detection
// "disable"
// anything else → strict whitelist; "=" prefix is added automatically
// when missing
IBHCA string
// contains filtered or unexported fields
}